@@ -263,7 +263,7 @@ RICHTEXT_SETTINGS = {
         "width": "700px",
         "height": "350px",
         "dialog_type": "modal",
-        "theme_advanced_blockformats": "h2,p",
+        "theme_advanced_blockformats": "h1,h2,h3,h4,h5,h6,p",
         "content_css": "css/screen.content.css",
         "extended_valid_elements": "iframe[scrolling|frameborder|class|id|src|width|height|name|align],article[id|class],section[id|class]",
         "convert_urls": False,
